
# About `devapp`


<p attr="autogenerated by make_badges"></p>

<p attr="autogenerated by make_badges"></p>

![](img/page-teaser.png){: style="width:1550px" }


This is an enabler repo to develop "ops friendly" apps in a normalized way, incl:

- logging ([structlog](https://www.structlog.org/en/stable/))
- cli flags handling ([abseil](https://abseil.io/docs/python/), with addons)
- docu ([mkdocs-material](https://squidfunk.github.io/mkdocs-material/getting-started/))
- project setup
- (test) resoures management, including daemons and container filesystem layers

and more.



<!-- pre_proc_marker -->


----


Last modified: Wed Aug 11 17:33:48 2021